@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2015 David R. MacIver
+# Most of this work is copyright (C) 2013-2016 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -17,8 +17,7 @@
 
 # coding: utf-8
 
-"""
-This file originates in the IPython project and is made use of under the
+"""This file originates in the IPython project and is made use of under the
 following licensing terms:
 
 The IPython licensing terms
@@ -55,6 +54,7 @@ LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 """
 
 from __future__ import division, print_function, absolute_import
@@ -237,10 +237,8 @@ def test_indentation():
 
 
 def test_dispatch():
-    """
-    Test correct dispatching: The _repr_pretty_ method for MyDict
-    must be found before the registered printer for dict.
-    """
+    """Test correct dispatching: The _repr_pretty_ method for MyDict must be
+    found before the registered printer for dict."""
     gotoutput = pretty.pretty(MyDict())
     expectedoutput = 'MyDict(...)'
 
@@ -264,7 +262,7 @@ def test_sets():
                 'frozenset({1, 2})', '{-3, -2, -1}']
     for obj, expected_output in zip(objects, expected):
         got_output = pretty.pretty(obj)
-        yield assert_equal, got_output, expected_output
+        assert_equal(got_output, expected_output)
 
 
 def test_unsortable_set():
@@ -346,7 +344,7 @@ class SB(SA):
 
 
 try:
-    super(SA).__thisclass__
+    super(SA).__self__
 
     def test_super_repr():
         output = pretty.pretty(super(SA))
