@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2015 David R. MacIver
+# Most of this work is copyright (C) 2013-2016 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -35,9 +35,8 @@ AVERAGE_LIST_LENGTH = 2
 
 
 def clamp(lower, value, upper):
-    """Given a value and optional lower/upper bounds, 'clamp' the
-    value so that it satisfies lower <= value <= upper.
-    """
+    """Given a value and optional lower/upper bounds, 'clamp' the value so that
+    it satisfies lower <= value <= upper."""
     if (lower is not None) and (upper is not None) and (lower > upper):
         raise ValueError('Cannot clamp with lower > upper: %r > %r' %
                          (lower, upper))
